# Changelog

## 0.0.2 (2026-01-29)

Full Changelog: [v0.0.1...v0.0.2](https://github.com/rayrift/python-sdk/compare/v0.0.1...v0.0.2)

### Chores

* configure new SDK language ([5a54a5c](https://github.com/rayrift/python-sdk/commit/5a54a5c271c977f2d58879dfa5cecc41b94e6bb0))
* update SDK settings ([a0c45d3](https://github.com/rayrift/python-sdk/commit/a0c45d3dbe88d1aa63837d34f092dddb26f9f910))
* update SDK settings ([8d32d3d](https://github.com/rayrift/python-sdk/commit/8d32d3d53522dbcc196f631596e620f7d2f90846))
